Function Refernce
=================

stuweparser.crawler module
--------------------------

.. automodule:: stuweparser.crawler
    :members:
    :undoc-members:
    :show-inheritance:

stuweparser.parser module
-------------------------

.. automodule:: stuweparser.parser
    :members:
    :undoc-members:
    :show-inheritance:

stuweparser.xml_generator module
--------------------------------

.. automodule:: stuweparser.xml_generator
    :members:
    :undoc-members:
    :show-inheritance:
